@@ -9,8 +9,7 @@ display_size = [0,0]
 eventsl = None
 system("clear")
 print("Pygame Extra 1.6.X is installed correctly!")
-scriptpath = str(__file__).replace("pygame-extra/__init__.py",'')
-print('at: ' + scriptpath)
+scriptpath = str(__file__).replace("__init__.py",'')
 #RESOURCE LOADING# \/
 slider_image = None
 #RESOURCE LOADING# /\
